@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -106,7 +106,7 @@ function draw_cdef_preview($cdef_id) {
 	?>
 	<tr class='even'>
 		<td style='padding:4px'>
-			<pre>cdef=<?php print get_cdef($cdef_id, true);?></pre>
+			<pre>cdef=<?php print html_escape(get_cdef($cdef_id, true));?></pre>
 		</td>
 	</tr>
 	<?php
@@ -201,7 +201,7 @@ function duplicate_cdef($_cdef_id, $cdef_title) {
 	$cdef_id = sql_save($save, 'cdef');
 
 	/* create new entry(s): cdef_items */
-	if (sizeof($cdef_items) > 0) {
+	if (cacti_sizeof($cdef_items) > 0) {
 		foreach ($cdef_items as $cdef_item) {
 			unset($save);
 
@@ -237,7 +237,7 @@ function form_actions() {
 				db_execute('DELETE FROM cdef WHERE ' . array_to_sql_or($selected_items, 'id'));
 				db_execute('DELETE FROM cdef_items WHERE ' . array_to_sql_or($selected_items, 'cdef_id'));
 			} elseif (get_nfilter_request_var('drp_action') == '2') { /* duplicate */
-				for ($i=0;($i<count($selected_items));$i++) {
+				for ($i=0;($i<cacti_count($selected_items));$i++) {
 					duplicate_cdef($selected_items[$i], get_nfilter_request_var('title_format'));
 				}
 			}
@@ -257,7 +257,7 @@ function form_actions() {
 			input_validate_input_number($matches[1]);
 			/* ==================================================== */
 
-			$cdef_list .= '<li>' . htmlspecialchars(db_fetch_cell_prepared('SELECT name FROM cdef WHERE id = ?', array($matches[1]))) . '</li>';
+			$cdef_list .= '<li>' . html_escape(db_fetch_cell_prepared('SELECT name FROM cdef WHERE id = ?', array($matches[1]))) . '</li>';
 			$cdef_array[$i] = $matches[1];
 
 			$i++;
@@ -268,40 +268,41 @@ function form_actions() {
 
 	form_start('cdef.php');
 
-	html_start_box($cdef_actions{get_nfilter_request_var('drp_action')}, '60%', '', '3', 'center', '');
+	html_start_box($cdef_actions[get_nfilter_request_var('drp_action')], '60%', '', '3', 'center', '');
 
-	if (isset($cdef_array) && sizeof($cdef_array)) {
+	if (isset($cdef_array) && cacti_sizeof($cdef_array)) {
 		if (get_nfilter_request_var('drp_action') == '1') { /* delete */
 			print "<tr>
 				<td class='textArea'>
-					<p>" . __n('Click \'Continue\' to delete the following CDEF.', 'Click \'Continue\' to delete all following CDEFs.', sizeof($cdef_array)) . "</p>
+					<p>" . __n('Click \'Continue\' to delete the following CDEF.', 'Click \'Continue\' to delete all following CDEFs.', cacti_sizeof($cdef_array)) . "</p>
 					<div class='itemlist'><ul>$cdef_list</ul></div>
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __n('Delete CDEF', 'Delete CDEFs', sizeof($cdef_array)) . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Delete CDEF', 'Delete CDEFs', cacti_sizeof($cdef_array)) . "'>";
 		} elseif (get_nfilter_request_var('drp_action') == '2') { /* duplicate */
 			print "<tr>
 				<td class='textArea'>
-					<p>" . __n('Click \'Continue\' to duplicate the following CDEF. You can optionally change the title format for the new CDEF.', 'Click \'Continue\' to duplicate the following CDEFs. You can optionally change the title format for the new CDEFs.', sizeof($cdef_array)) . "</p>
+					<p>" . __n('Click \'Continue\' to duplicate the following CDEF. You can optionally change the title format for the new CDEF.', 'Click \'Continue\' to duplicate the following CDEFs. You can optionally change the title format for the new CDEFs.', cacti_sizeof($cdef_array)) . "</p>
 					<div class='itemlist'><ul>$cdef_list</ul></div>
 					<p>" . __('Title Format:') . '<br>';
 					form_text_box('title_format', '<cdef_title> (1)', '', '255', '30', 'text'); print "</p>
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __n('Duplicate CDEF', 'Duplicate CDEFs', sizeof($cdef_array)) . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Duplicate CDEF', 'Duplicate CDEFs', cacti_sizeof($cdef_array)) . "'>";
 		}
 	} else {
-		print "<tr><td class='odd'><span class='textError'>" . __('You must select at least one CDEF.') . "</span></td></tr>\n";
-		$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
+		raise_message(40);
+		header('Location: cdef.php?header=false');
+		exit;
 	}
 
 	print "<tr>
 		<td class='saveRow'>
 			<input type='hidden' name='action' value='actions'>
 			<input type='hidden' name='selected_items' value='" . (isset($cdef_array) ? serialize($cdef_array) : '') . "'>
-			<input type='hidden' name='drp_action' value='" . get_nfilter_request_var('drp_action') . "'>
+			<input type='hidden' name='drp_action' value='" . html_escape(get_nfilter_request_var('drp_action')) . "'>
 			$save_html
 		</td>
 	</tr>";
@@ -325,6 +326,9 @@ function cdef_item_remove_confirm() {
 	get_filter_request_var('cdef_id');
 	/* ==================================================== */
 
+	/* sort the cdef functions */
+	asort($cdef_functions);
+
 	form_start('cdef.php');
 
 	html_start_box('', '100%', '', '3', 'center', '');
@@ -336,14 +340,14 @@ function cdef_item_remove_confirm() {
 	<tr>
 		<td class='topBoxAlt'>
 			<p><?php print __('Click \'Continue\' to delete the following CDEF Item.');?></p>
-			<p><?php print __('CDEF Name: \'%s\'', $cdef['name']);?><br>
-			<em><?php $cdef_item_type = $cdef_item['type']; print $cdef_item_types[$cdef_item_type];?></em>: <strong><?php print get_cdef_item_name($cdef_item['id']);?></strong></p>
+			<p><?php print __esc('CDEF Name: %s', $cdef['name']);?><br>
+			<em><?php $cdef_item_type = $cdef_item['type']; print $cdef_item_types[$cdef_item_type];?></em>: <strong><?php print html_escape(get_cdef_item_name($cdef_item['id']));?></strong></p>
 		</td>
 	</tr>
 	<tr>
-		<td align='right'>
-			<input id='cancel' type='button' value='<?php print __esc('Cancel');?>' onClick='$("#cdialog").dialog("close");$(".deleteMarker").blur();' name='cancel'>
-			<input id='continue' type='button' value='<?php print __esc('Continue');?>' name='continue' title='<?php print __esc('Remove CDEF Item');?>'>
+		<td class='right'>
+			<input type='button' class='ui-button ui-corner-all ui-widget' id='cancel' value='<?php print __esc('Cancel');?>' onClick='$("#cdialog").dialog("close");$(".deleteMarker").blur();' name='cancel'>
+			<input type='button' class='ui-button ui-corner-all ui-widget' id='continue' value='<?php print __esc('Continue');?>' name='continue' title='<?php print __esc('Remove CDEF Item');?>'>
 		</td>
 	</tr>
 	<?php
@@ -351,26 +355,6 @@ function cdef_item_remove_confirm() {
 	html_end_box();
 
 	form_end();
-
-	?>
-	<script type='text/javascript'>
-	$(function() {
-		$('#cdialog').dialog();
-
-		$('#continue').click(function(data) {
-			$.post('cdef.php?action=item_remove', {
-				__csrf_magic: csrfMagicToken,
-				cdef_id: <?php print get_request_var('cdef_id');?>,
-				id: <?php print get_request_var('id');?>
-			}, function(data) {
-				$('#cdialog').dialog('close');
-				$('.deleteMarker').blur();
-				loadPageNoHeader('cdef.php?action=edit&header=false&id=<?php print get_request_var('id');?>');
-			});
-		});
-	});
-	</script>
-	<?php
 }
 
 function cdef_item_remove() {
@@ -416,19 +400,35 @@ function item_edit() {
 	get_filter_request_var('cdef_id');
 	/* ==================================================== */
 
+	/* sort the cdef functions */
+	asort($cdef_functions);
+
 	if (!isempty_request_var('id')) {
-		$cdef = db_fetch_row_prepared('SELECT * FROM cdef_items WHERE id = ?', array(get_request_var('id')));
-		$current_type = $cdef['type'];
-		$values[$current_type] = $cdef['value'];
+		$cdef = db_fetch_row_prepared('SELECT *
+			FROM cdef_items
+			WHERE id = ?',
+			array(get_request_var('id')));
+
+		if (cacti_sizeof($cdef)) {
+			$current_type = $cdef['type'];
+			$values[$current_type] = $cdef['value'];
+		}
+	} else {
+		$cdef = array();
 	}
 
 	html_start_box(__('CDEF Preview'), '100%', '', '3', 'center', '');
 	draw_cdef_preview(get_request_var('cdef_id'));
 	html_end_box();
 
-	form_start('cdef.php', 'form_cdef');
+	form_start('cdef.php', 'chk');
 
-	html_start_box( __('CDEF Items [edit: %s]', htmlspecialchars(db_fetch_cell_prepared('SELECT name FROM cdef WHERE id = ?', array(get_request_var('cdef_id'))))), '100%', '', '3', 'center', '');
+	$cdef_name = db_fetch_cell_prepared('SELECT name
+		FROM cdef
+		WHERE id = ?',
+		array(get_request_var('cdef_id')));
+
+	html_start_box(__esc('CDEF Items [edit: %s]', $cdef_name), '100%', '', '3', 'center', '');
 
 	if (isset_request_var('type_select')) {
 		$current_type = get_request_var('type_select');
@@ -438,61 +438,85 @@ function item_edit() {
 		$current_type = '1';
 	}
 
-	form_alternate_row();?>
-		<td style='width:50%;'>
-			<span class='textEditTitle'><?php print __('CDEF Item Type');?></span><br>
-			<?php print __('Choose what type of CDEF item this is.');?>
-		</td>
-		<td>
-			<select id='type_select'>
-				<?php
-				foreach ($cdef_item_types as $var => $val) {
-					print "<option value='cdef.php?action=item_edit" . get_request_var('id') . '&cdef_id=' . get_request_var('cdef_id') . "&type_select=$var'"; if ($var == $current_type) { print ' selected'; } print ">$val</option>\n";
-				}
-				?>
-			</select>
-            <script type='text/javascript'>
-            $(function() {
-                $('#type_select').change(function() {
-                    loadPageNoHeader('cdef.php?action=item_edit&header=false&cdef_id=<?php print get_request_var('cdef_id');?>&type_select='+$('#type_select').val())
-                });
-            });
-            </script>
-		</td>
-	</tr>
-	<?php form_alternate_row();?>
-		<td style='width:50%;'>
-			<span class='textEditTitle'><?php print __('CDEF Item Value');?></span><br>
-			<?php print __('Enter a value for this CDEF item.');?>
-		</td>
-		<td>
-			<?php
-			switch ($current_type) {
-			case '1':
-				form_dropdown('value', $cdef_functions, '', '', (isset($cdef['value']) ? $cdef['value'] : ''), '', '');
-				break;
-			case '2':
-				form_dropdown('value', $cdef_operators, '', '', (isset($cdef['value']) ? $cdef['value'] : ''), '', '');
-				break;
-			case '4':
-				form_dropdown('value', $custom_data_source_types, '', '', (isset($cdef['value']) ? $cdef['value'] : ''), '', '');
-				break;
-			case '5':
-				form_dropdown('value', db_fetch_assoc('SELECT name, id FROM cdef WHERE system=0 ORDER BY name'), 'name', 'id', (isset($cdef['value']) ? $cdef['value'] : ''), '', '');
-				break;
-			case '6':
-				form_text_box('value', (isset($cdef['value']) ? $cdef['value'] : ''), '', '255', 30, 'text', isset_request_var('id') ? get_request_var('id') : '0');
-				break;
-			}
-			?>
-		</td>
-	</tr>
-	<?php
+	$form_cdef = array(
+		'type_select' => array(
+			'method'        => 'drop_array',
+			'friendly_name' => __('CDEF Item Type'),
+			'description'   => __('Choose what type of CDEF item this is.'),
+			'value'         => $current_type,
+			'array'         => $cdef_item_types
+		),
+		'value' => array(
+			'method'        => 'drop_array',
+			'friendly_name' => __('CDEF Item Value'),
+			'description'   => __('Enter a value for this CDEF item.'),
+			'value'         => (isset($cdef['value']) ? $cdef['value']:'')
+		),
+		'id' => array(
+			'method'        => 'hidden',
+			'value'         => isset_request_var('id') ?  get_request_var('id') : '0',
+		),
+		'type' => array(
+			'method'        => 'hidden',
+			'value'         => $current_type
+		),
+		'cdef_id' => array(
+			'method'        => 'hidden',
+			'value'         => get_request_var('cdef_id')
+		),
+		'save_component_item' => array(
+			'method'        => 'hidden',
+			'value'         => '1'
+		)
+	);
 
-	form_hidden_box('id', (isset_request_var('id') ? get_request_var('id') : '0'), '');
-	form_hidden_box('type', $current_type, '');
-	form_hidden_box('cdef_id', get_request_var('cdef_id'), '');
-	form_hidden_box('save_component_item', '1', '');
+	switch ($current_type) {
+	case '1':
+		$form_cdef['value']['array'] = $cdef_functions;
+
+		break;
+	case '2':
+		$form_cdef['value']['array'] = $cdef_operators;
+
+		break;
+	case '4':
+		$form_cdef['value']['array'] = $custom_data_source_types;
+
+		break;
+	case '5':
+		$form_cdef['value']['method'] = 'drop_sql';
+		$form_cdef['value']['sql']    = 'SELECT name, id FROM cdef WHERE `system` = 0 ORDER BY name';
+
+		break;
+	case '6':
+		$form_cdef['value']['method']     = 'textbox';
+		$form_cdef['value']['max_length'] = '255';
+		$form_cdef['value']['size']       = '30';
+
+		break;
+	}
+
+	draw_edit_form(
+		array(
+			'config' => array('no_form_tag' => true),
+			'fields' => inject_form_variables($form_cdef, $cdef)
+		)
+	);
+
+	?>
+	<script type='text/javascript'>
+	$(function() {
+		$('#type_select').unbind().change(function() {
+			strURL  = 'cdef.php?action=item_edit';
+			strURL += '&id=' + $('#id').val();
+			strURL += '&cdef_id=' + $('#cdef_id').val();
+			strURL += '&type_select=' + $('#type_select').val();
+			strURL += '&header=false';
+			loadPageNoHeader(strURL);
+		});
+	});
+	</script>
+	<?php
 
 	html_end_box();
 
@@ -508,40 +532,25 @@ function cdef_item_dnd() {
 	get_filter_request_var('id');
 	/* ================= Input validation ================= */
 
-	if (!isset_request_var('cdef_item') || !is_array(get_nfilter_request_var('cdef_item'))) exit;
+	$continue = true;
 
-	/* cdef table contains one row defined as 'nodrag&nodrop' */
-	unset($_REQUEST['cdef_item'][0]);
+	if (isset_request_var('cdef_item') && is_array(get_nfilter_request_var('cdef_item'))) {
+		$cdef_ids = get_nfilter_request_var('cdef_item');
 
-	/* delivered cdef ids has to be exactly the same like we have stored */
-	$old_order = array();
+		if (cacti_sizeof($cdef_ids)) {
+			$sequence = 1;
+			foreach($cdef_ids as $cdef_id) {
+				$cdef_id = str_replace('line', '', $cdef_id);
+				input_validate_input_number($cdef_id);
 
-	foreach(get_nfilter_request_var('cdef_item') as $sequence => $cdef_id) {
-		if (empty($cdef_id)) continue;
-		$new_order[$sequence] = str_replace('line', '', $cdef_id);
-	}
+				db_execute_prepared('UPDATE cdef_items
+					SET sequence = ?
+					WHERE id = ?',
+					array($sequence, $cdef_id));
 
-	$cdef_items = db_fetch_assoc_prepared('SELECT id, sequence FROM cdef_items WHERE cdef_id = ?', array(get_request_var('id')));
-
-	if(sizeof($cdef_items)) {
-		foreach($cdef_items as $item) {
-			$old_order[$item['sequence']] = $item['id'];
+				$sequence++;
+			}
 		}
-	}else {
-		exit;
-	}
-
-	if (sizeof(array_diff($new_order, $old_order))>0) exit;
-
-	/* the set of sequence numbers has to be the same too */
-	if (sizeof(array_diff_key($new_order, $old_order))>0) exit;
-	/* ==================================================== */
-
-	foreach($new_order as $sequence => $cdef_id) {
-		input_validate_input_number($sequence);
-		input_validate_input_number($cdef_id);
-
-		db_execute_prepared('UPDATE cdef_items SET sequence = ? WHERE id = ?', array($sequence, $cdef_id));
 	}
 
 	header('Location: cdef.php?action=edit&header=false&id=' . get_request_var('id'));
@@ -556,7 +565,7 @@ function cdef_edit() {
 
 	if (!isempty_request_var('id')) {
 		$cdef = db_fetch_row_prepared('SELECT * FROM cdef WHERE id = ?', array(get_request_var('id')));
-		$header_label = __('CDEF [edit: %s]', htmlspecialchars($cdef['name']));
+		$header_label = __esc('CDEF [edit: %s]', $cdef['name']);
 	} else {
 		$header_label = __('CDEF [new]');
 	}
@@ -579,7 +588,7 @@ function cdef_edit() {
 		draw_cdef_preview(get_request_var('id'));
 		html_end_box();
 
-		html_start_box( __('CDEF Items'), '100%', '', '3', 'center', 'cdef.php?action=item_edit&cdef_id=' . $cdef['id']);
+		html_start_box(__('CDEF Items'), '100%', '', '3', 'center', 'cdef.php?action=item_edit&cdef_id=' . $cdef['id']);
 
 		$display_text = array(
 			array('display' => __('Item'), 'align' => 'left'),
@@ -588,36 +597,40 @@ function cdef_edit() {
 
 		html_header($display_text, 2);
 
-		$cdef_items = db_fetch_assoc_prepared('SELECT * FROM cdef_items WHERE cdef_id = ? ORDER BY sequence', array(get_request_var('id')));
+		$cdef_items = db_fetch_assoc_prepared('SELECT *
+			FROM cdef_items
+			WHERE cdef_id = ?
+			ORDER BY sequence',
+			array(get_request_var('id')));
 
 		$i = 1;
-		$total_items = sizeof($cdef_items);
-		if (sizeof($cdef_items)) {
+		$total_items = cacti_sizeof($cdef_items);
+		if (cacti_sizeof($cdef_items)) {
 			foreach ($cdef_items as $cdef_item) {
 				form_alternate_row('line' . $cdef_item['id'], true, true);?>
 					<td>
-						<a class='linkEditMain' href='<?php print htmlspecialchars('cdef.php?action=item_edit&id=' . $cdef_item['id'] . '&cdef_id=' . $cdef['id']);?>'><?php print __('Item #%d', $i);?></a>
+						<a class='linkEditMain' href='<?php print html_escape('cdef.php?action=item_edit&id=' . $cdef_item['id'] . '&cdef_id=' . $cdef['id']);?>'><?php print __('Item #%d', $i);?></a>
 					</td>
 					<td>
-						<em><?php $cdef_item_type = $cdef_item['type']; print $cdef_item_types[$cdef_item_type];?></em>: <?php print htmlspecialchars(get_cdef_item_name($cdef_item['id']));?>
+						<em><?php $cdef_item_type = $cdef_item['type']; print $cdef_item_types[$cdef_item_type];?></em>: <?php print html_escape(get_cdef_item_name($cdef_item['id']));?>
 					</td>
 					<td class='right'>
 						<?php
 						if (read_config_option('drag_and_drop') == '') {
 							if ($i < $total_items && $total_items > 0) {
-								echo '<a class="pic fa fa-caret-down moveArrow" href="' . htmlspecialchars('cdef.php?action=item_movedown&id=' . $cdef_item['id'] . '&cdef_id=' . $cdef_item['cdef_id']) . '" title="' . __esc('Move Down') . '"></a>';
+								echo '<a class="pic fa fa-caret-down moveArrow" href="' . html_escape('cdef.php?action=item_movedown&id=' . $cdef_item['id'] . '&cdef_id=' . $cdef_item['cdef_id']) . '" title="' . __esc('Move Down') . '"></a>';
 							} else {
 								echo '<span class="moveArrowNone"></span>';
 							}
 
 							if ($i > 1 && $i <= $total_items) {
-								echo '<a class="pic fa fa-caret-up moveArrow" href="' . htmlspecialchars('cdef.php?action=item_moveup&id=' . $cdef_item['id'] .	'&cdef_id=' . $cdef_item['cdef_id']) . '" title="' . __esc('Move Up') . '"></a>';
+								echo '<a class="pic fa fa-caret-up moveArrow" href="' . html_escape('cdef.php?action=item_moveup&id=' . $cdef_item['id'] .	'&cdef_id=' . $cdef_item['cdef_id']) . '" title="' . __esc('Move Up') . '"></a>';
 							} else {
 								echo '<span class="moveArrowNone"></span>';
 							}
 						}
 						?>
-						<a id='<?php print $cdef['id'] . '_' . $cdef_item['id'];?>' class='delete deleteMarker fa fa-remove' title='<?php print __esc('Delete');?>' href='#'></a>
+						<a id='<?php print $cdef['id'] . '_' . $cdef_item['id'];?>' class='delete deleteMarker fa fa-times' title='<?php print __esc('Delete');?>' href='#'></a>
 					</td>
 				</tr>
 				<?php
@@ -637,7 +650,7 @@ function cdef_edit() {
 	$(function() {
 		$('#cdef_edit3').find('.cactiTable').attr('id', 'cdef_item');
 		$('.cdialog').remove();
-		$('body').append("<div class='cdialog' id='cdialog'></div>");
+		$('#main').append("<div class='cdialog' id='cdialog'></div>");
 
 		<?php if (read_config_option('drag_and_drop') == 'on') { ?>
 		$('#cdef_item').tableDnD({
@@ -647,19 +660,40 @@ function cdef_edit() {
 		});
 		<?php } ?>
 
-		$('.delete').click(function (event) {
+		$('.delete').click(function(event) {
 			event.preventDefault();
 
 			id = $(this).attr('id').split('_');
 			request = 'cdef.php?action=item_remove_confirm&id='+id[0]+'&cdef_id='+id[1];
-			$.get(request, function(data) {
-				$('#cdialog').html(data);
-				applySkin();
-				$('#cdialog').dialog({ title: '<?php print __('Delete CDEF Item');?>', minHeight: 80, minWidth: 500 });
-			});
-		}).css('cursor', 'pointer');
-	});
+			$.get(request)
+				.done(function(data) {
+					$('#cdialog').html(data);
 
+					applySkin();
+
+					$('#continue').off('click').on('click', function(data) {
+						$.post('cdef.php?action=item_remove', {
+							__csrf_magic: csrfMagicToken,
+							cdef_id: id[1],
+							id: id[0]
+						}).done(function(data) {
+							$('#cdialog').dialog('close');
+							$('.deleteMarker').blur();
+							loadPageNoHeader('cdef.php?action=edit&header=false&id='+id[0]);
+						});
+					});
+
+					$('#cdialog').dialog({
+						title: '<?php print __('Delete CDEF Item');?>',
+						minHeight: 80,
+						minWidth: 500
+					});
+				})
+				.fail(function(data) {
+					getPresentHTTPError(data);
+				});
+		});
+	});
 	</script>
 	<?php
 }
@@ -679,10 +713,9 @@ function cdef() {
 			'default' => '1'
 			),
 		'filter' => array(
-			'filter' => FILTER_CALLBACK,
+			'filter' => FILTER_DEFAULT,
 			'pageset' => true,
-			'default' => '',
-			'options' => array('options' => 'sanitize_search_string')
+			'default' => ''
 			),
 		'sort_column' => array(
 			'filter' => FILTER_CALLBACK,
@@ -711,7 +744,7 @@ function cdef() {
 		$rows = get_request_var('rows');
 	}
 
-	html_start_box( __('CDEFs'), '100%', '', '3', 'center', 'cdef.php?action=edit');
+	html_start_box(__('CDEFs'), '100%', '', '3', 'center', 'cdef.php?action=edit');
 
 	?>
 	<tr class='even'>
@@ -723,7 +756,7 @@ function cdef() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input id='filter' type='text' name='filter' size='25' value='<?php print html_escape_request_var('filter');?>'>
+						<input type='text' class='ui-state-default ui-corner-all' id='filter' name='filter' size='25' value='<?php print html_escape_request_var('filter');?>'>
 					</td>
 					<td>
 						<?php print __('CDEFs');?>
@@ -732,9 +765,9 @@ function cdef() {
 						<select id='rows' name='rows' onChange='applyFilter()'>
 							<option value='-1'<?php print (get_request_var('rows') == '-1' ? ' selected>':'>') . __('Default');?></option>
 							<?php
-							if (sizeof($item_rows) > 0) {
+							if (cacti_sizeof($item_rows) > 0) {
 								foreach ($item_rows as $key => $value) {
-									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . htmlspecialchars($value) . "</option>\n";
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 								}
 							}
 							?>
@@ -748,8 +781,8 @@ function cdef() {
 					</td>
 					<td>
 						<span>
-							<input type='button' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
-							<input type='button' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
 						</span>
 					</td>
 				</tr>
@@ -798,9 +831,9 @@ function cdef() {
 
 	/* form the 'where' clause for our main sql query */
 	if (get_request_var('filter') != '') {
-		$sql_where = "WHERE (name LIKE '%" . get_request_var('filter') . "%' AND system=0)";
+		$sql_where = 'WHERE (name LIKE ' . db_qstr('%' . get_request_var('filter') . '%') . ' AND `system` = 0)';
 	} else {
-		$sql_where = 'WHERE system=0';
+		$sql_where = 'WHERE `system` = 0';
 	}
 
 	if (get_request_var('has_graphs') == 'true') {
@@ -815,7 +848,10 @@ function cdef() {
 			SELECT cd.id AS `rows`,
 			SUM(CASE WHEN local_graph_id>0 THEN 1 ELSE 0 END) AS graphs
 			FROM cdef AS cd
-			LEFT JOIN graph_templates_item AS gti
+			LEFT JOIN (
+				SELECT DISTINCT cdef_id, local_graph_id, graph_template_id
+				FROM graph_templates_item
+			) AS gti
 			ON gti.cdef_id=cd.id
 			$sql_where
 			GROUP BY cd.id
@@ -831,9 +867,12 @@ function cdef() {
 		FROM (
 			SELECT cd.*, gti.local_graph_id
 			FROM cdef AS cd
-			LEFT JOIN graph_templates_item AS gti
+			LEFT JOIN (
+				SELECT DISTINCT cdef_id, local_graph_id, graph_template_id
+				FROM graph_templates_item
+			) AS gti
 			ON gti.cdef_id=cd.id
-			WHERE system=0
+			WHERE `system` = 0
 			GROUP BY cd.id, gti.graph_template_id, gti.local_graph_id
 		) AS rs
 		$sql_where
@@ -859,7 +898,7 @@ function cdef() {
 	html_header_sort_checkbox($display_text, get_request_var('sort_column'), get_request_var('sort_direction'), false);
 
 	$i = 0;
-	if (sizeof($cdef_list)) {
+	if (cacti_sizeof($cdef_list)) {
 		foreach ($cdef_list as $cdef) {
 			if ($cdef['graphs'] == 0 && $cdef['templates'] == 0) {
 				$disabled = false;
@@ -869,19 +908,19 @@ function cdef() {
 
 			form_alternate_row('line' . $cdef['id'], false, $disabled);
 			form_selectable_cell(filter_value($cdef['name'], get_request_var('filter'), 'cdef.php?action=edit&id=' . $cdef['id']), $cdef['id']);
-			form_selectable_cell($disabled ? __('No') : __('Yes'), $cdef['id'], '', 'text-align:right');
-			form_selectable_cell(number_format_i18n($cdef['graphs'], '-1'), $cdef['id'], '', 'text-align:right');
-			form_selectable_cell(number_format_i18n($cdef['templates'], '-1'), $cdef['id'], '', 'text-align:right');
+			form_selectable_cell($disabled ? __('No'):__('Yes'), $cdef['id'], '', 'right');
+			form_selectable_cell(number_format_i18n($cdef['graphs'], '-1'), $cdef['id'], '', 'right');
+			form_selectable_cell(number_format_i18n($cdef['templates'], '-1'), $cdef['id'], '', 'right');
 			form_checkbox_cell($cdef['name'], $cdef['id'], $disabled);
 			form_end_row();
 		}
 	} else {
-		print "<tr class='tableRow'><td colspan='4'><em>" . __('No CDEFs') . "</em></td></tr>\n";
+		print "<tr class='tableRow'><td colspan='" . (cacti_sizeof($display_text)+1) . "'><em>" . __('No CDEFs') . "</em></td></tr>\n";
 	}
 
 	html_end_box(false);
 
-	if (sizeof($cdef_list)) {
+	if (cacti_sizeof($cdef_list)) {
 		print $nav;
 	}
 
