@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -85,10 +85,10 @@ function form_save() {
 		$save['id']        = get_nfilter_request_var('id');
 
 		if (get_nfilter_request_var('read_only') == '') {
-			$save['name']      = get_nfilter_request_var('name');
+			$save['name']      = get_filter_request_var('name', FILTER_SANITIZE_SPECIAL_CHARS);
 			$save['hex']       = form_input_validate(get_nfilter_request_var('hex'),  'hex',  '^[a-fA-F0-9]+$' , false, 3);
 		} else {
-			$save['name']      = get_nfilter_request_var('hidden_name');
+			$save['name']      = get_filter_request_var('hidden_name', FILTER_SANITIZE_SPECIAL_CHARS);
 			$save['read_only'] = 'on';
 		}
 
@@ -113,7 +113,7 @@ function form_save() {
 				$csv_data = file($_FILES['import_file']['tmp_name']);
 				$debug_data = color_import_processor($csv_data);
 
-				if (sizeof($debug_data)) {
+				if (cacti_sizeof($debug_data)) {
 					$_SESSION['import_debug_info'] = $debug_data;
 				}
 
@@ -167,7 +167,7 @@ function form_actions() {
 
 			$color = db_fetch_row_prepared('SELECT name, hex FROM colors WHERE id = ?', array($matches[1]));
 
-			$color_list .= '<li>' . ($color['name'] != '' ? htmlspecialchars($color['name']): __('Unnamed Color')) . ' (<span style="background-color:#' . $color['hex'] . '">' . $color['hex'] . '</span>)</li>';
+			$color_list .= '<li>' . ($color['name'] != '' ? html_escape($color['name']): __('Unnamed Color')) . ' (<span style="background-color:#' . $color['hex'] . '">' . $color['hex'] . '</span>)</li>';
 			$color_array[$i] = $matches[1];
 
 			$i++;
@@ -178,22 +178,23 @@ function form_actions() {
 
 	form_start('color.php');
 
-	html_start_box($color_actions{get_nfilter_request_var('drp_action')}, '60%', '', '3', 'center', '');
+	html_start_box($color_actions[get_nfilter_request_var('drp_action')], '60%', '', '3', 'center', '');
 
-	if (isset($color_array) && sizeof($color_array)) {
+	if (isset($color_array) && cacti_sizeof($color_array)) {
 		if (get_nfilter_request_var('drp_action') == '1') { /* delete */
 			print "<tr>
 				<td class='textArea' class='odd'>
-					<p>" . __n('Click \'Continue\' to delete the following Color', 'Click \'Continue\' to delete the following Colors', sizeof($color_array)) . "</p>
+					<p>" . __n('Click \'Continue\' to delete the following Color', 'Click \'Continue\' to delete the following Colors', cacti_sizeof($color_array)) . "</p>
 					<div class='itemlist'><ul>$color_list</ul></div>
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __n('Delete Color', 'Delete Colors', sizeof($color_array)) . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Delete Color', 'Delete Colors', cacti_sizeof($color_array)) . "'>";
 		}
 	} else {
-		print "<tr><td class='odd'><span class='textError'>" . __('You must select at least one Color.') . "</span></td></tr>\n";
-		$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
+		raise_message(40);
+		header('Location: color.php?header=false');
+		exit;
 	}
 
 	print "<tr>
@@ -217,7 +218,7 @@ function color_import_processor(&$colors) {
 	$hexcol = 0;
 	$return_array = array();
 
-	if (sizeof($colors)) {
+	if (cacti_sizeof($colors)) {
 		foreach($colors as $color_line) {
 			/* parse line */
 			$line_array = explode(',', $color_line);
@@ -230,7 +231,7 @@ function color_import_processor(&$colors) {
 				$required = 0;
 				$update_suffix = '';
 
-				if (sizeof($line_array)) {
+				if (cacti_sizeof($line_array)) {
 				foreach($line_array as $line_item) {
 					$line_item = trim(str_replace("'", '', $line_item));
 					$line_item = trim(str_replace('"', '', $line_item));
@@ -279,7 +280,7 @@ function color_import_processor(&$colors) {
 			$first_column = true;
 			$sql_where = '';
 
-			if (sizeof($line_array)) {
+			if (cacti_sizeof($line_array)) {
 			foreach($line_array as $line_item) {
 				if (in_array($j, $insert_columns)) {
 					$line_item = trim(str_replace("'", '', $line_item));
@@ -318,7 +319,7 @@ function color_import_processor(&$colors) {
 					/* perform check to see if the row exists */
 					$existing_row = db_fetch_row("SELECT * FROM colors $sql_where");
 
-					if (sizeof($existing_row)) {
+					if (cacti_sizeof($existing_row)) {
 						array_push($return_array,"<strong>INSERT SKIPPED, EXISTING:</strong> $save_value");
 					} else {
 						$sql_execute = 'INSERT INTO colors ' . $save_order .
@@ -342,7 +343,7 @@ function color_import_processor(&$colors) {
 }
 
 function color_import() {
-	print "<form method='post' action='color.php?action=import' enctype='multipart/form-data'>\n";
+	form_start('color.php?action=import', '', true);
 
 	if ((isset($_SESSION['import_debug_info'])) && (is_array($_SESSION['import_debug_info']))) {
 		html_start_box('Import Results', '100%', '', '3', 'center', '');
@@ -351,7 +352,7 @@ function color_import() {
 			<p class='textArea'>" . __('Cacti has imported the following items:') . "</p>
 		</td></tr>\n";
 
-		if (sizeof($_SESSION['import_debug_info'])) {
+		if (cacti_sizeof($_SESSION['import_debug_info'])) {
 			foreach($_SESSION['import_debug_info'] as $import_result) {
 				print "<tr class='even'><td>" . $import_result . "</td></tr>\n";
 			}
@@ -368,7 +369,7 @@ function color_import() {
 		<td width='50%'><font class='textEditTitle'><?php print __('Import Colors from Local File'); ?></font><br>
 			<?php print __('Please specify the location of the CSV file containing your Color information.');?>
 		</td>
-		<td align='left'>
+		<td class='left'>
 			<div>
 				<label class='import_label' for='import_file'><?php print __('Select a File'); ?></label>
 				<input class='import_button' type='file' id='import_file' name='import_file'>
@@ -380,7 +381,7 @@ function color_import() {
 		<td width='50%'><font class='textEditTitle'><?php print __('Overwrite Existing Data?');?></font><br>
 			<?php print __('Should the import process be allowed to overwrite existing data?  Please note, this does not mean delete old rows, only update duplicate rows.');?>
 		</td>
-		<td align='left'>
+		<td class='left'>
 			<input type='checkbox' name='allow_update' id='allow_update'><?php print __('Allow Existing Rows to be Updated?');?>
 		</td><?php
 
@@ -413,7 +414,7 @@ function color_edit() {
 
 	if (!isempty_request_var('id')) {
 		$color = db_fetch_row_prepared('SELECT * FROM colors WHERE id = ?', array(get_request_var('id')));
-		$header_label = __('Colors [edit: %s]', $color['hex']);
+		$header_label = __esc('Colors [edit: %s]', $color['hex']);
 	} else {
 		$header_label = __('Colors [new]');
 	}
@@ -473,10 +474,9 @@ function process_request_vars() {
 			'default' => '1'
 			),
 		'filter' => array(
-			'filter' => FILTER_CALLBACK,
+			'filter' => FILTER_DEFAULT,
 			'pageset' => true,
-			'default' => '',
-			'options' => array('options' => 'sanitize_search_string')
+			'default' => ''
 			),
 		'sort_column' => array(
 			'filter' => FILTER_CALLBACK,
@@ -529,7 +529,7 @@ function color() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input id='filter' type='text' name='filter' size='25' value='<?php print html_escape_request_var('filter');?>'>
+						<input type='text' class='ui-state-default ui-corner-all' id='filter' name='filter' size='25' value='<?php print html_escape_request_var('filter');?>'>
 					</td>
 					<td>
 						<?php print __('Colors');?>
@@ -538,9 +538,9 @@ function color() {
 						<select id='rows' onChange='applyFilter()'>
 							<option value='-1'<?php print (get_request_var('rows') == '-1' ? ' selected>':'>') . __('Default');?></option>
 							<?php
-							if (sizeof($item_rows) > 0) {
+							if (cacti_sizeof($item_rows) > 0) {
 								foreach ($item_rows as $key => $value) {
-									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . htmlspecialchars($value) . "</option>\n";
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 								}
 							}
 							?>
@@ -560,14 +560,14 @@ function color() {
 					</td>
 					<td>
 						<span>
-							<input type='button' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
-							<input type='button' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
 						</span>
 					</td>
 					<td>
 						<span>
-							<input type='button' id='import' value='<?php print __esc('Import');?>' title='<?php print __esc('Import Colors');?>'>
-							<input type='button' id='export' value='<?php print __esc('Export');?>' title='<?php print __esc('Export Colors');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='import' value='<?php print __esc('Import');?>' title='<?php print __esc('Import Colors');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='export' value='<?php print __esc('Export');?>' title='<?php print __esc('Export Colors');?>'>
 						</span>
 					</td>
 				</tr>
@@ -618,6 +618,7 @@ function color() {
 				$('#export').click(function(event) {
 					strURL = 'color.php?action=export&header=false';
 					document.location = strURL;
+					Pace.stop();
 				});
 			});
 			</script>
@@ -629,8 +630,8 @@ function color() {
 
 	/* form the 'where' clause for our main sql query */
 	if (get_request_var('filter') != '') {
-		$sql_where = "WHERE (name LIKE '%" . get_request_var('filter') . "%'
-			OR hex LIKE '%" .  get_request_var('filter') . "%')";
+		$sql_where = 'WHERE (name LIKE ' . db_qstr('%' . get_request_var('filter') . '%') . '
+			OR hex LIKE ' . db_qstr('%' .  get_request_var('filter') . '%') . ')';
 	} else {
 		$sql_where = '';
 	}
@@ -686,7 +687,7 @@ function color() {
 		$sql_order
 		$sql_limit");
 
-    $nav = html_nav_bar('color.php?filter=' . get_request_var('filter'), MAX_DISPLAY_PAGES, get_request_var('page'), $rows, $total_rows, 8, 'Colors', 'page', 'main');
+    $nav = html_nav_bar('color.php?filter=' . get_request_var('filter'), MAX_DISPLAY_PAGES, get_request_var('page'), $rows, $total_rows, 8, __('Colors'), 'page', 'main');
 
 	form_start('color.php', 'chk');
 
@@ -707,7 +708,7 @@ function color() {
 	html_header_sort_checkbox($display_text, get_request_var('sort_column'), get_request_var('sort_direction'), false);
 
 	$i = 0;
-	if (sizeof($colors)) {
+	if (cacti_sizeof($colors)) {
 		foreach ($colors as $color) {
 			if ($color['graphs'] == 0 && $color['templates'] == 0) {
 				$disabled = false;
@@ -720,7 +721,7 @@ function color() {
 			}
 
 			form_alternate_row('line' . $color['id'], false, $disabled);
-			form_selectable_cell("<a class='linkEditMain' href='" . htmlspecialchars('color.php?action=edit&id=' . $color['id']) . "'>" . $color['hex'] . '</a>', $color['id']);
+			form_selectable_cell("<a class='linkEditMain' href='" . html_escape('color.php?action=edit&id=' . $color['id']) . "'>" . $color['hex'] . '</a>', $color['id']);
 			form_selectable_cell(filter_value($color['name'], get_request_var('filter')), $color['id']);
 			form_selectable_cell($color['read_only'] == 'on' ? __('Yes'):__('No'), $color['id']);
 			form_selectable_cell('', $color['id'], '', 'text-align:right;background-color:#' . $color['hex'] . ';min-width:30%');
@@ -736,7 +737,7 @@ function color() {
 
 	html_end_box(false);
 
-	if (sizeof($colors)) {
+	if (cacti_sizeof($colors)) {
 		print $nav;
 	}
 
@@ -751,8 +752,8 @@ function color_export() {
 
 	/* form the 'where' clause for our main sql query */
 	if (get_request_var('filter') != '') {
-		$sql_where = "WHERE (name LIKE '%" . get_request_var('filter') . "%'
-			OR hex LIKE '%" .  get_request_var('filter') . "%')";
+		$sql_where = 'WHERE (name LIKE ' . db_qstr('%' . get_request_var('filter') . '%') . '
+			OR hex LIKE ' . db_qstr('%' .  get_request_var('filter') . '%') . ')';
 	} else {
 		$sql_where = '';
 	}
@@ -784,7 +785,7 @@ function color_export() {
 		GROUP BY rs.id
 		$sql_having");
 
-	if (sizeof($colors)) {
+	if (cacti_sizeof($colors)) {
 		header('Content-type: application/csv');
 		header('Content-Disposition: attachment; filename=colors.csv');
 
