@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -26,7 +26,8 @@ include_once('./include/auth.php');
 
 $aggregate_actions = array(
 	1 => __('Delete'),
-	2 => __('Duplicate')
+	2 => __('Duplicate'),
+	3 => __('Sync Aggregates')
 );
 
 /* set default action */
@@ -77,9 +78,9 @@ function draw_color_template_items_list($item_list, $filename, $url_data, $disab
 	html_header($display_text, 2);
 
 	$i = 1;
-	$total_items = sizeof($item_list);
+	$total_items = cacti_sizeof($item_list);
 
-	if (sizeof($item_list)) {
+	if (cacti_sizeof($item_list)) {
 		foreach ($item_list as $item) {
 			/* alternating row color */
 			form_alternate_row('line' . $item['color_template_item_id'], true, true);
@@ -87,7 +88,7 @@ function draw_color_template_items_list($item_list, $filename, $url_data, $disab
 			print '<td>';
 
 			if ($disable_controls == false) {
-				print "<a class='linkEditMain' href='" . htmlspecialchars($filename . '?action=item_edit&color_template_item_id=' . $item['color_template_item_id'] . "&$url_data") . "'>";
+				print "<a class='linkEditMain' href='" . html_escape($filename . '?action=item_edit&color_template_item_id=' . $item['color_template_item_id'] . "&$url_data") . "'>";
 			}
 
 			print __('Item # %d', $i);
@@ -107,19 +108,19 @@ function draw_color_template_items_list($item_list, $filename, $url_data, $disab
 
 				if (read_config_option('drag_and_drop') == '') {
 					if ($i < $total_items && $total_items > 1) {
-						echo '<a class="pic fa fa-caret-down moveArrow" href="' . htmlspecialchars('color_templates_items.php?action=item_movedown&color_template_item_id=' . $item['color_template_item_id'] . '&color_template_id=' . $item['color_template_id']) . '" title="' . __esc('Move Down') . '"></a>';
+						echo '<a class="pic fa fa-caret-down moveArrow" href="' . html_escape('color_templates_items.php?action=item_movedown&color_template_item_id=' . $item['color_template_item_id'] . '&color_template_id=' . $item['color_template_id']) . '" title="' . __esc('Move Down') . '"></a>';
 					} else {
 						echo '<span class="moveArrowNone"></span>';
 					}
 
 					if ($i > 1 && $i <= $total_items) {
-						echo '<a class="pic fa fa-caret-up moveArrow" href="' . htmlspecialchars('color_templates_items.php?action=item_moveup&color_template_item_id=' . $item['color_template_item_id'] . '&color_template_id=' . $item['color_template_id']) . '" title="' . __esc('Move Up') . '"></a>';
+						echo '<a class="pic fa fa-caret-up moveArrow" href="' . html_escape('color_templates_items.php?action=item_moveup&color_template_item_id=' . $item['color_template_item_id'] . '&color_template_id=' . $item['color_template_id']) . '" title="' . __esc('Move Up') . '"></a>';
 					} else {
 						echo '<span class="moveArrowNone"></span>';
 					}
 				}
 
-				print "<a class='delete deleteMarker fa fa-remove' id='" .  $item['color_template_id'] . '_' . $item['color_template_item_id'] . "' title='" . __esc('Delete') . "'></a>";
+				print "<a class='delete deleteMarker fa fa-times' id='" .  $item['color_template_id'] . '_' . $item['color_template_item_id'] . "' title='" . __esc('Delete') . "'></a>";
 
 				print "</td>\n";
 			}
@@ -147,7 +148,7 @@ function aggregate_color_form_save() {
 			$save1['color_template_id'] = 0;
 		}
 
-		$save1['name'] = form_input_validate(get_nfilter_request_var('name'), 'name', '', false, 3);
+		$save1['name'] = form_input_validate(get_filter_request_var('name', FILTER_SANITIZE_SPECIAL_CHARS), 'name', '', false, 3);
 
 		cacti_log('Saved ID: ' . $save1['color_template_id'] . ' Name: ' . $save1['name'], false, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
 
@@ -190,9 +191,13 @@ function aggregate_color_form_actions() {
 				db_execute('DELETE FROM color_templates WHERE ' . array_to_sql_or($selected_items, 'color_template_id'));
 				db_execute('DELETE FROM color_template_items WHERE ' . array_to_sql_or($selected_items, 'color_template_id'));
 			} elseif (get_nfilter_request_var('drp_action') == '2') { // duplicate
-				for ($i=0;($i<count($selected_items));$i++) {
+				for ($i=0;($i<cacti_count($selected_items));$i++) {
 					duplicate_color_template($selected_items[$i], get_nfilter_request_var('title_format'));
 				}
+			} elseif (get_nfilter_request_var('drp_action') == '3') { // sync templates
+				for ($i=0;($i<cacti_count($selected_items));$i++) {
+					sync_color_templates($selected_items[$i]);
+				}
 			}
 		}
 
@@ -209,7 +214,13 @@ function aggregate_color_form_actions() {
 			/* ================= input validation ================= */
 			input_validate_input_number($matches[1]);
 			/* ==================================================== */
-			$color_list .= '<li>' . htmlspecialchars(db_fetch_cell_prepared('SELECT name FROM color_templates WHERE color_template_id = ?', array($matches[1]))) . '</li>';
+
+			$name = db_fetch_cell_prepared('SELECT name
+				FROM color_templates
+				WHERE color_template_id = ?',
+				array($matches[1]));
+
+			$color_list .= '<li>' . html_escape($name) . '</li>';
 			$color_array[] = $matches[1];
 		}
 	}
@@ -220,30 +231,42 @@ function aggregate_color_form_actions() {
 
 	html_start_box($aggregate_actions[get_nfilter_request_var('drp_action')], '60%', '', '3', 'center', '');
 
-	if (isset($color_array) && sizeof($color_array)) {
+	if (isset($color_array) && cacti_sizeof($color_array)) {
 		if (get_request_var('drp_action') == '1') { /* delete */
 			print "<tr>
 				<td class='textArea'>
-					<p>" . __n('Click \'Continue\' to delete the following Color Template', 'Click \'Continue\' to delete following Color Templates', sizeof($color_array)) . "</p>
+					<p>" . __n('Click \'Continue\' to delete the following Color Template', 'Click \'Continue\' to delete following Color Templates', cacti_sizeof($color_array)) . "</p>
 					<div class='itemlist'><ul>$color_list</ul></div>
 				</td>
-			</tr>\n";
+			</tr>";
 
-			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __n('Delete Color Template', 'Delete Color Templates', sizeof($color_array)) . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Delete Color Template', 'Delete Color Templates', cacti_sizeof($color_array)) . "'>";
 		} elseif (get_request_var('drp_action') == '2') { // duplicate
 			print "<tr>
 				<td class='textArea'>
-					<p>" . __n('Click \'Continue\' to duplicate the following Color Template. You can optionally change the title format for the new color template.', 'Click \'Continue\' to duplicate following Color Templates. You can optionally change the title format for the new color templates.', sizeof($color_array)) . "</p>
+					<p>" . __n('Click \'Continue\' to duplicate the following Color Template. You can optionally change the title format for the new color template.', 'Click \'Continue\' to duplicate following Color Templates. You can optionally change the title format for the new color templates.', cacti_sizeof($color_array)) . "</p>
 					<div class='itemlist'><ul>$color_list</ul></div>
-					<p>" . __('Title Format:') . "<br>"; form_text_box('title_format', '<template_title> (1)', '', '255', '30', 'text'); print "</p>
+					<p>" . __('Title Format:') . '<br>';
+					form_text_box('title_format', '<template_title> (1)', '', '255', '30', 'text');
+					print "</p>
 				</td>
-			</tr>\n";
+			</tr>";
 
-			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __n('Duplicate Color Template', 'Duplicate Color Templates', sizeof($color_array)) . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Duplicate Color Template', 'Duplicate Color Templates', cacti_sizeof($color_array)) . "'>";
+		} elseif (get_request_var('drp_action') == '3') { // sync
+			print "<tr>
+				<td class='textArea'>
+					<p>" . __n('Click \'Continue\' to Synchronize all Aggregate Graphs with the selected Color Template.', 'Click \'Continue\' to Syncrhonize all Aggregate Graphs with the selected Color Templates.', cacti_sizeof($color_array)) . "</p>
+					<div class='itemlist'><ul>$color_list</ul></div></p>
+				</td>
+			</tr>";
+
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Synchronize Color Template', 'Synchronize Color Templates', cacti_sizeof($color_array)) . "'>";
 		}
 	} else {
-		print "<tr><td class='even'><span class='textError'>" . __('You must select at least one Color Template.') . "</span></td></tr>\n";
-		$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
+		raise_message(40);
+		header('Location: color_templates.php?header=false');
+		exit;
 	}
 
 	print "<tr>
@@ -286,47 +309,62 @@ function aggregate_color_item() {
 			ORDER BY cti.sequence ASC',
 			array(get_request_var('color_template_id')));
 
-		$header_label = __('Color Template Items [edit: %s]', db_fetch_cell_prepared('SELECT name FROM color_templates WHERE color_template_id = ?', array(get_request_var('color_template_id'))));
+		$name = db_fetch_cell_prepared('SELECT name
+			FROM color_templates
+			WHERE color_template_id = ?',
+			array(get_request_var('color_template_id')));
+
+		$header_label = __esc('Color Template Items [edit: %s]', $name);
 	}
 
-	html_start_box($header_label, '100%', '', '3', 'center', 'color_templates_items.php?action=item_edit&color_template_id=' . htmlspecialchars(get_request_var('color_template_id')));
+	html_start_box($header_label, '100%', '', '3', 'center', 'color_templates_items.php?action=item_edit&color_template_id=' . html_escape_request_var('color_template_id'));
 
-	draw_color_template_items_list($template_item_list, 'color_templates_items.php', 'color_template_id=' . htmlspecialchars(get_request_var('color_template_id')), false);
+	draw_color_template_items_list($template_item_list, 'color_templates_items.php', 'color_template_id=' . html_escape_request_var('color_template_id'), false);
 
 	html_end_box();
 
     ?>
-    <script type='text/javascript'>
+	<script type='text/javascript'>
 
-    $(function() {
-        $('#color_templates_template_edit2_child').attr('id', 'color_item');
-        $('.cdialog').remove();
-        $('body').append("<div class='cdialog' id='cdialog'></div>");
+	$(function() {
+		$('#color_templates_template_edit2_child').attr('id', 'color_item');
+		$('.cdialog').remove();
+		$('#main').append("<div class='cdialog' id='cdialog'></div>");
 
 		<?php if (read_config_option('drag_and_drop') == 'on') { ?>
-        $('#color_item').tableDnD({
-            onDrop: function(table, row) {
-                loadPageNoHeader('color_templates_items.php?action=ajax_dnd&id=<?php isset_request_var('color_template_id') ? print get_request_var('color_template_id') : print 0;?>&'+$.tableDnD.serialize());
-            }
-        });
+		$('#color_item').tableDnD({
+			onDrop: function(table, row) {
+				loadPageNoHeader('color_templates_items.php?action=ajax_dnd&id=<?php isset_request_var('color_template_id') ? print get_request_var('color_template_id') : print 0;?>&'+$.tableDnD.serialize());
+			}
+		});
 		<?php } ?>
 
-        $('.delete').click(function (event) {
-            event.preventDefault();
+		$('.delete').click(function (event) {
+			event.preventDefault();
 
-            id = $(this).attr('id').split('_');
-            request = 'color_templates_items.php?action=item_remove_confirm&id='+id[0]+'&color_id='+id[1];
-            $.get(request, function(data) {
-                $('#cdialog').html(data);
-                applySkin();
-                $('#cdialog').dialog({ title: '<?php print __('Delete Color Item');?>', minHeight: 80, minWidth: 500 });
-            });
-        }).css('cursor', 'pointer');
-    });
+			id = $(this).attr('id').split('_');
+			request = 'color_templates_items.php?action=item_remove_confirm&id='+id[0]+'&color_id='+id[1];
+			$.get(request)
+				.done(function(data) {
+					$('#cdialog').html(data);
 
-    </script>
-    <?php
+					applySkin();
 
+					$('#cdialog').dialog({
+						title: '<?php print __('Delete Color Item');?>',
+						close: function () { $('.delete').blur(); $('.selectable').removeClass('selected'); },
+						minHeight: 80,
+						minWidth: 500
+					});
+				})
+				.fail(function(data) {
+					getPresentHTTPError(data);
+				});
+		}).css('cursor', 'pointer');
+	});
+
+	</script>
+	<?php
 }
 
 /* ----------------------------
@@ -346,7 +384,7 @@ function aggregate_color_template_edit() {
 
 	if (!isempty_request_var('color_template_id')) {
 		$template = db_fetch_row_prepared('SELECT * FROM color_templates WHERE color_template_id = ?', array(get_request_var('color_template_id')));
-		$header_label = __('Color Template [edit: %s]', $template['name']);
+		$header_label = __esc('Color Template [edit: %s]', $template['name']);
 	} else {
 		$header_label = __('Color Template [new]');
 	}
@@ -376,6 +414,60 @@ function aggregate_color_template_edit() {
 }
 
 
+function sync_color_templates($color_template) {
+	global $config;
+
+	include_once($config['base_path'] . '/lib/api_aggregate.php');
+
+	$name = db_fetch_cell_prepared('SELECT name
+		FROM color_templates
+		WHERE color_template_id = ?',
+		array($color_template));
+
+	$aggregate_templates = array_rekey(
+		db_fetch_assoc_prepared('SELECT DISTINCT aggregate_template_id
+			FROM aggregate_graph_templates_item
+			WHERE color_template = ?',
+			array($color_template)),
+		'aggregate_template_id', 'aggregate_template_id'
+	);
+
+	$found     = false;
+	$templates = 0;
+	$graphs    = 0;
+
+	if (cacti_sizeof($aggregate_templates)) {
+		$found = true;
+		$templates = cacti_sizeof($aggregate_templates);
+		foreach($aggregate_templates as $id) {
+			push_out_aggregates($id);
+		}
+	}
+
+	$aggregate_graphs = db_fetch_assoc_prepared('SELECT DISTINCT ag.aggregate_template_id, ag.local_graph_id
+		FROM aggregate_graphs_graph_item AS agi
+		LEFT JOIN aggregate_graphs AS ag
+		ON ag.id=agi.aggregate_graph_id
+		WHERE (ag.aggregate_template_id > 0 AND ag.template_propogation = "")
+		OR ag.aggregate_template_id = 0
+		AND agi.color_template = ?',
+		array($color_template));
+
+	if (cacti_sizeof($aggregate_graphs)) {
+		$found = true;
+		$graphs = cacti_sizeof($aggregate_graphs);
+		foreach($aggregate_templates as $id) {
+			push_out_aggregates($id['aggregate_template_id'], $id['local_graph_id']);
+		}
+	}
+
+	if ($found) {
+		raise_message('color_template_sync', __('Color Template \'%s\' had %d Aggregate Templates pushed out and %d Non-Templated Aggregates pushed out', $name, $templates, $graphs), MESSAGE_LEVEL_INFO);
+	} else {
+		raise_message('color_template_sync', __('Color Template \'%s\' had no Aggregate Templates or Graphs using this Color Template.', $name, $templates, $graphs), MESSAGE_LEVEL_INFO);
+	}
+}
+
 /**
  * aggregate_color_template		maintain color templates
  */
@@ -395,10 +487,9 @@ function aggregate_color_template() {
 			'default' => '1'
 			),
 		'filter' => array(
-			'filter' => FILTER_CALLBACK,
+			'filter' => FILTER_DEFAULT,
 			'pageset' => true,
-			'default' => '',
-			'options' => array('options' => 'sanitize_search_string')
+			'default' => ''
 			),
 		'sort_column' => array(
 			'filter' => FILTER_CALLBACK,
@@ -429,29 +520,31 @@ function aggregate_color_template() {
 
 	form_start('color_templates.php', 'form_template');
 
-	html_start_box( __('Color Templates'), '100%', '', '3', 'center', 'color_templates.php?action=template_edit');
+	html_start_box(__('Color Templates'), '100%', '', '3', 'center', 'color_templates.php?action=template_edit');
 
 	$filter_html = '<tr class="even">
+		<td>
+			<table class="filterTable">
+				<tr>
 					<td>
-					<table class="filterTable">
-						<tr>
-							<td>
-								' . __('Search') . '
-							</td>
-							<td>
-								<input type="text" id="filter" size="25" value="' . html_escape_request_var('filter') . '">
-							</td>
-							<td>
-								' . __('Color Templates') . '
-							</td>
-							<td>
-								<select id="rows" onChange="applyFilter()">
-								<option value="-1" ';
+						' . __('Search') . '
+					</td>
+					<td>
+						<input type="text" class="ui-state-default ui-corner-all" id="filter" size="25" value="' . html_escape_request_var('filter') . '">
+					</td>
+					<td>
+						' . __('Color Templates') . '
+					</td>
+					<td>
+						<select id="rows" onChange="applyFilter()">
+							<option value="-1" ';
 	if (get_request_var('rows') == '-1') {
 		$filter_html .= 'selected';
 	}
+
 	$filter_html .= '>' . __('Default') . '</option>';
-	if (sizeof($item_rows) > 0) {
+
+	if (cacti_sizeof($item_rows)) {
 		foreach ($item_rows as $key => $value) {
 			$filter_html .= "<option value='" . $key . "'";
 			if (get_request_var('rows') == $key) {
@@ -460,35 +553,36 @@ function aggregate_color_template() {
 			$filter_html .= '>' . $value . "</option>\n";
 		}
 	}
-	$filter_html .= '					</select>
-							</td>
-							<td>
-								<span>
-									<input type="checkbox" id="has_graphs" ' . (get_request_var('has_graphs') == 'true' ? 'checked':'') . ' onChange="applyFilter()">
-									<label for="has_graphs">' . __('Has Graphs') . '</label>
-								</span>
-							</td>
-							<td>
-								<span>
-									<input type="button" id="refresh" value="' . __esc('Go') . '">
-									<input type="button" id="clear" value="' . __esc('Clear') . '">
-								</span>
-							</td>
-						</tr>
-					</table>
+
+	$filter_html .= '			</select>
 					</td>
-				</tr>';
+					<td>
+						<span>
+							<input type="checkbox" id="has_graphs" ' . (get_request_var('has_graphs') == 'true' ? 'checked':'') . ' onChange="applyFilter()">
+							<label for="has_graphs">' . __('Has Graphs') . '</label>
+						</span>
+					</td>
+					<td>
+						<span>
+							<input type="button" class="ui-button ui-corner-all ui-widget" id="refresh" value="' . __esc('Go') . '">
+							<input type="button" class="ui-button ui-corner-all ui-widget" id="clear" value="' . __esc('Clear') . '">
+						</span>
+					</td>
+				</tr>
+			</table>
+			</td>
+		</tr>';
 
 	print $filter_html;
 
 	html_end_box();
 
-	print "</form>\n";
+	form_end();
 
 	/* form the 'where' clause for our main sql query */
 	$sql_where = '';
 	if (get_request_var('filter') != '') {
-		$sql_where = "WHERE (ct.name LIKE '%" . get_request_var('filter') . "%')";
+		$sql_where = 'WHERE (ct.name LIKE ' . db_qstr('%' . get_request_var('filter') . '%') . ')';
 	}
 
 	if (get_request_var('has_graphs') == 'true') {
@@ -543,7 +637,7 @@ function aggregate_color_template() {
 	html_start_box('', '100%', '', '3', 'center', '');
 
 	$display_text = array(
-		'name'      => array( __('Template Title'), 'ASC'),
+		'name'      => array(__('Template Title'), 'ASC'),
 		'nosort'    => array('display' => __('Deletable'), 'align' => 'right', 'tip' => __('Color Templates that are in use cannot be Deleted. In use is defined as being referenced by an Aggregate Template.')),
 		'graphs'    => array('display' => __('Graphs'), 'align' => 'right', 'sort' => 'DESC'),
 		'templates' => array('display' => __('Templates'), 'align' => 'right', 'sort' => 'DESC')
@@ -551,7 +645,7 @@ function aggregate_color_template() {
 
 	html_header_sort_checkbox($display_text, get_request_var('sort_column'), get_request_var('sort_direction'), false);
 
-	if (sizeof($template_list)) {
+	if (cacti_sizeof($template_list)) {
 		foreach ($template_list as $template) {
 			if ($template['templates'] > 0) {
 				$disabled = true;
@@ -562,19 +656,19 @@ function aggregate_color_template() {
 			form_alternate_row('line' . $template['color_template_id'], true);
 
 			form_selectable_cell(filter_value($template['name'], get_request_var('filter'), 'color_templates.php?action=template_edit&color_template_id=' . $template['color_template_id'] . '&page=1'), $template['color_template_id']);
-			form_selectable_cell($disabled ? __('No') : __('Yes'), $template['color_template_id'], '', 'text-align:right');
-            form_selectable_cell(number_format_i18n($template['graphs']), $template['color_template_id'], '', 'text-align:right;');
-            form_selectable_cell(number_format_i18n($template['templates']), $template['color_template_id'], '', 'text-align:right;');
+			form_selectable_cell($disabled ? __('No'):__('Yes'), $template['color_template_id'], '', 'right');
+			form_selectable_cell(number_format_i18n($template['graphs']), $template['color_template_id'], '', 'right');
+			form_selectable_cell(number_format_i18n($template['templates']), $template['color_template_id'], '', 'right');
 			form_checkbox_cell($template['name'], $template['color_template_id'], $disabled);
 			form_end_row();
 		}
 	} else {
-		print "<tr><td><em>" . __('No Color Templates Found') ."</em></td></tr>\n";
+		print "<tr class='tableRow'><td colspan='" . (cacti_sizeof($display_text)+1) . "'><em>" . __('No Color Templates Found') ."</em></td></tr>\n";
 	}
 
 	html_end_box(false);
 
-	if (sizeof($template_list)) {
+	if (cacti_sizeof($template_list)) {
 		print $nav;
 	}
 
