@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -128,6 +128,14 @@ define('POLLER_VERBOSITY_HIGH', 4);
 define('POLLER_VERBOSITY_DEBUG', 5);
 define('POLLER_VERBOSITY_DEVDBG', 6);
 
+define('POLLER_STATUS_NEW', 0);
+define('POLLER_STATUS_RUNNING', 1);
+define('POLLER_STATUS_IDLE', 2);
+define('POLLER_STATUS_DOWN', 3);
+define('POLLER_STATUS_DISABLED', 4);
+define('POLLER_STATUS_RECOVERING', 5);
+define('POLLER_STATUS_HEARTBEAT', 6);
+
 define('AVAIL_NONE', 0);
 define('AVAIL_SNMP_AND_PING', 1);
 define('AVAIL_SNMP', 2);
@@ -277,9 +285,10 @@ define('REPORTS_TYPE_INLINE_JPG_LN', 92);
 define('REPORTS_TYPE_INLINE_GIF_LN', 93);
 
 define('REPORTS_ITEM_GRAPH', 1);
-define('REPORTS_ITEM_TEXT', 2);
-define('REPORTS_ITEM_TREE', 3);
-define('REPORTS_ITEM_HR', 4);
+define('REPORTS_ITEM_TEXT',  2);
+define('REPORTS_ITEM_TREE',  3);
+define('REPORTS_ITEM_HR',    4);
+define('REPORTS_ITEM_HOST',  5);
 
 define('REPORTS_ALIGN_LEFT', 1);
 define('REPORTS_ALIGN_CENTER', 2);
@@ -383,9 +392,10 @@ if (isset($database_type) && $database_type == 'mysql') {
 define('MAX_DISPLAY_PAGES', 5);
 define('CHECKED', 'on');
 
-define('FILTER_VALIDATE_IS_REGEX',          99999);
-define('FILTER_VALIDATE_IS_NUMERIC_ARRAY', 100000);
-define('FILTER_VALIDATE_IS_NUMERIC_LIST',  100001);
+define('FILTER_VALIDATE_MAX_DATE_AS_INT', 2088385563);
+define('FILTER_VALIDATE_IS_REGEX',             99999);
+define('FILTER_VALIDATE_IS_NUMERIC_ARRAY',    100000);
+define('FILTER_VALIDATE_IS_NUMERIC_LIST',     100001);
 
 /* socket errors */
 define('ENOTSOCK',        88);
@@ -450,7 +460,16 @@ define('GRAPH_SOURCE_DATA_QUERY', 1);
 define('GRAPH_SOURCE_TEMPLATE', 2);
 define('GRAPH_SOURCE_AGGREGATE', 3);
 
-define('CACTI_LANGUAGE_HANDLER_NONE', 0);
+define('CACTI_LANGUAGE_HANDLER_DEFAULT', 0);
 define('CACTI_LANGUAGE_HANDLER_PHPGETTEXT', 1);
 define('CACTI_LANGUAGE_HANDLER_OSCAROTERO', 2);
 define('CACTI_LANGUAGE_HANDLER_MOTRANSLATOR', 3);
+
+if (!defined('LDAP_OPT_X_TLS_NEVER')) {
+	define('LDAP_OPT_X_TLS_NEVER', 0);
+	define('LDAP_OPT_X_TLS_HARD', 1);
+	define('LDAP_OPT_X_TLS_DEMAND', 2);
+	define('LDAP_OPT_X_TLS_ALLOW', 3);
+	define('LDAP_OPT_X_TLS_TRY', 4);
+}
+
